@@ -14,46 +14,28 @@
  *  GNU General Public License for more details.
  */
 
-
-#ifndef __MEDIALIBSEARCHMODEL_H__
-#define __MEDIALIBSEARCHMODEL_H__
+#ifndef __MEDIALIB_SEARCH_MODEL_H__
+#define __MEDIALIB_SEARCH_MODEL_H__
 
 #include "xclient.h"
-#include "playlistmodel.h"
+#include "collectionmodel.h"
 
-#include <QStandardItemModel>
-
-class MedialibSearchModel : public PlaylistModel
+class MedialibSearchModel : public CollectionModel
 {
 	Q_OBJECT
 	public:
-		enum {
-			SEARCH_ALL,
-			SEARCH_ARTIST,
-			SEARCH_ALBUM,
-			SEARCH_TITLE,
-			SEARCH_YEAR
-		};
-
+	    enum Key {
+            ARTIST,
+            ALBUM,
+            TITLE,
+            YEAR,
+            ALL
+        };
 		MedialibSearchModel (QObject *parent, XClient *client);
-		void do_search (uint32_t, const QString &, bool unav=false);
-		void got_connection (XClient *client);
-
-		QMimeData *mimeData (const QModelIndexList &list) const;
-
-		Qt::DropActions supportedDropActions () const {
-			return Qt::IgnoreAction;
-		};
-		QStringList mimeTypes () const {
-			return QStringList ("application/x-xmms2mlibid");
-		};
-
-
-	signals:
-		void searchDone ();
-
-	private:
-		bool handle_search (const Xmms::List<Xmms::Dict> &);
+        void search (uint32_t key, const QString &, const bool &);
+    private:
+        std::string key_as_string (uint32_t);
 };
 
 #endif
+
