@@ -24,7 +24,7 @@ class FileDialog : public QFileDialog
 {
 	Q_OBJECT
 	public:
-		FileDialog (QWidget *parent, const QString &name);
+		FileDialog (QWidget *parent, const QString &name, const bool &remote=false);
 		QString getDirectory ();
 		QStringList getFiles ();
 
