@@ -1,4 +1,4 @@
-/** 
+/**
  *  This file is a part of Esperanza, an XMMS2 Client.
  *
  *  Copyright (C) 2005-2006 XMMS2 Team
@@ -31,38 +31,57 @@
 #include "preferences.h"
 #include "minimode.h"
 #include "mdns.h"
+#include "filehandler.h"
 
 int
 main (int argc, char **argv)
 {
-	QApplication app(argc, argv);
-
-	QCoreApplication::setOrganizationName ("xmms2");
+    QCoreApplication::setOrganizationName ("xmms2");
 	QCoreApplication::setOrganizationDomain ("xmms.org");
 	QCoreApplication::setApplicationName ("Esperanza");
 
+    QSettings s;
+
+    if (s.value("core/ignoredesktopsettings", false).toBool ()) {
+        QApplication::setDesktopSettingsAware (false);
+    }
+
+	QApplication app(argc, argv);
+
+#if QT_VERSION >= 0x040200 && QT_VERSION < 0x040300
+	if (app.style ()->objectName () == "motif") {
+	    qWarning ("Qt 4.2 is running and the Motif style is selected. We'll switch to plastique so you won't hate us.");
+	    app.setStyle(new QPlastiqueStyle());
+	}
+#endif
+
 	QApplication::setWindowIcon (QIcon (":images/esperanza.png"));
 
 	QString locale = QLocale::system ().name ();
 
 	PreferenceDialog::save_defaults ();
-	QSettings s;
 
 	QTranslator trans;
 	if (!s.value ("core/skiplocales").toBool ()) {
 		trans.load (QString ("esperanza_") + locale, ":translations");
 		app.installTranslator (&trans);
 	}
-	
+
 	XClient client (NULL, "Esperanza");
 
 	MDNSQuery mdns (NULL);
 	mdns.browse_service ("_xmms2._tcp");
 
+	/*
+	RemoteFileHandler handler (&client);
+	*/
+
 	QString path;
 
 	PlayerWidget *pw = new PlayerWidget (NULL, &client);
 
+	char *p = NULL;
+
 browser:
 	if (!getenv ("XMMS_PATH")) {
 		ServerDialog sd (NULL, &mdns);
@@ -71,16 +90,19 @@ browser:
 		} else {
 			path = sd.get_path ();
 		}
+
 		if (path == "local") {
-			path = "";
+			p = NULL;
 		} else if (path.isNull ()) {
 			return EXIT_FAILURE;
+		} else {
+			p = path.toAscii ().data ();
 		}
 	} else {
-		path = QString::fromAscii (getenv ("XMMS_PATH"));
+		p = getenv ("XMMS_PATH");
 	}
 
-	if (!client.connect (path.toStdString ())) {
+	if (!client.connect (p)) {
 		if (!getenv ("XMMS_PATH")) {
 			goto browser;
 		} else {
@@ -91,8 +113,11 @@ browser:
 		}
 	}
 
-
-	pw->show ();
+	if (!s.value("ui/minimode", false).toBool ()) {
+		pw->show ();
+	} else {
+		pw->toggle_mini ();
+	}
 
 	return app.exec ();
 }
