@@ -1,4 +1,4 @@
-/** 
+/**
  *  This file is a part of Esperanza, an XMMS2 Client.
  *
  *  Copyright (C) 2005-2006 XMMS2 Team
@@ -15,11 +15,13 @@
  */
 
 
+
 #include "medialibdialog.h"
-#include "medialibsearchmodel.h"
+#include "collectionmodel.h"
 
 #include "playerbutton.h"
 #include "progressindicator.h"
+#include "medialibsearchmodel.h"
 
 #include <QLabel>
 #include <QSettings>
@@ -32,35 +34,36 @@
 #include <QCheckBox>
 #include <QCompleter>
 
-MedialibDialog::MedialibDialog (QWidget *parent, XClient *client) : QDialog (parent)
+MedialibDialog::MedialibDialog (QWidget *parent, XClient *client) : QMainWindow (parent)
 {
 	QSettings s;
 
-	setModal (false);
+	setWindowFlags (Qt::Dialog);
 	setAttribute (Qt::WA_DeleteOnClose);
-	setWindowTitle ("Esperanza - Medialib");
+	setWindowTitle ("Esperanza - Medialib Search");
 
-	QGridLayout *g = new QGridLayout (this);
+	QWidget *base = new QWidget (this);
+	setCentralWidget (base);
+
+	QGridLayout *g = new QGridLayout (base);
 
 	m_client = client;
 	m_completer = NULL;
 
-	m_qb = new QComboBox (this);
-	m_qb->addItem (tr ("All"), MedialibSearchModel::SEARCH_ALL);
-	m_qb->addItem (tr ("Artist"), MedialibSearchModel::SEARCH_ARTIST);
-	m_qb->addItem (tr ("Album"), MedialibSearchModel::SEARCH_ALBUM);
-	m_qb->addItem (tr ("Title"), MedialibSearchModel::SEARCH_TITLE);
-	m_qb->addItem (tr ("Year"), MedialibSearchModel::SEARCH_YEAR);
+	m_qb = new QComboBox (base);
+	m_qb->addItem (tr ("All"), MedialibSearchModel::ALL);
+	m_qb->addItem (tr ("Artist"), MedialibSearchModel::ARTIST);
+	m_qb->addItem (tr ("Album"), MedialibSearchModel::ALBUM);
+	m_qb->addItem (tr ("Title"), MedialibSearchModel::TITLE);
+	m_qb->addItem (tr ("Year"), MedialibSearchModel::YEAR);
+
 
-	m_qb->setCurrentIndex (s.value ("medialib/searchdef", 0).toInt ());
-	connect (m_qb, SIGNAL (currentIndexChanged (int)), this, SLOT (load_compl_list (int)));
-	
 	g->addWidget (m_qb, 0, 0, 1, 1);
 
-	QLabel *l = new QLabel (tr ("="), this);
+	QLabel *l = new QLabel (tr ("="), base);
 	g->addWidget (l, 0, 1, 1, 1);
 
-	m_le = new QLineEdit (this);
+	m_le = new QLineEdit (base);
 	m_le->setFocus (Qt::OtherFocusReason);
 	m_le->setFocusPolicy (Qt::StrongFocus);
 	connect (m_le, SIGNAL (returnPressed ()), this, SLOT (do_search ()));
@@ -68,18 +71,32 @@ MedialibDialog::MedialibDialog (QWidget *parent, XClient *client) : QDialog (par
 	g->addWidget (m_le, 0, 2, 1, 1);
 	g->setColumnStretch (2, 1);
 
-	m_indicator = new ProgressIndicator (this);
+	m_indicator = new ProgressIndicator (base);
 	g->addWidget (m_indicator, 0, 3, 1, 1);
 
-	m_list = new MedialibView (this, client);
-	g->addWidget (m_list, 1, 0, 1, 4);
+    PlayerButton *expand = new PlayerButton (base, ":images/minmax.png");
+    g->addWidget (expand, 0, 4, 1, 1);
+    connect (expand, SIGNAL (clicked (QMouseEvent *)),
+             this, SLOT (expand_clicked ()));
 
-	QWidget *dummy = new QWidget (this);
+    m_browser = new MedialibPaneBrowser (this, m_client);
+    if (!s.value ("medialib/paneopen", false).toBool ()) {
+        m_browser->hide ();
+    } else {
+        m_le->setEnabled (false);
+        m_qb->setEnabled (false);
+    }
+    g->addWidget (m_browser, 1, 0, 1, 5);
+
+	m_list = new MedialibView (base, client);
+	g->addWidget (m_list, 2, 0, 1, 5);
+
+	QWidget *dummy = new QWidget (base);
 	QHBoxLayout *hbox = new QHBoxLayout (dummy);
 
-	g->setRowStretch (1, 1);
+	g->setRowStretch (2, 1);
 
-	m_cb = new QCheckBox (tr ("Display non-available entries"), dummy);
+	m_cb = new QCheckBox (tr ("Display unavailable entries"), dummy);
 	hbox->addWidget (m_cb);
 	connect (m_cb, SIGNAL (stateChanged (int)), this, SLOT (do_search ()));
 
@@ -96,40 +113,83 @@ MedialibDialog::MedialibDialog (QWidget *parent, XClient *client) : QDialog (par
 
 	hbox->addWidget (plus);
 	hbox->addWidget (stop);
-	g->addWidget (dummy, 2, 0, 1, 4);
+	g->addWidget (dummy, 3, 0, 1, 5);
 	g->setMargin (1);
 
 	resize (s.value ("medialibdialog/size", QSize (500, 350)).toSize ());
 
 	connect (m_list, SIGNAL (searchDone ()), this, SLOT (search_done ()));
 
+	m_qb->setCurrentIndex (s.value ("medialib/searchdef", 0).toInt ());
+
 	load_compl_list (m_qb->currentIndex ());
+    connect (m_qb, SIGNAL (currentIndexChanged (int)), this, SLOT (load_compl_list (int)));
+}
+
+void
+MedialibDialog::expand_clicked ()
+{
+    QSettings s;
+
+    if (m_browser->isVisible ()) {
+        m_browser->hide ();
+        m_le->setEnabled (true);
+        m_qb->setEnabled (true);
+        load_compl_list (m_qb->currentIndex ());
+        s.setValue ("medialib/paneopen", QVariant (false));
+    } else {
+        m_browser->show ();
+        m_le->setEnabled (false);
+        m_qb->setEnabled (false);
+        s.setValue ("medialib/paneopen", QVariant (true));
+    }
 }
 
 void
 MedialibDialog::load_compl_list (int i)
 {
+    QSettings s;
+
+    if (s.value ("medialib/paneopen").toBool ()) {
+        return;
+    }
+
+    if (!s.value ("medialib/completion").toBool ()) {
+        return;
+    }
+
 	int t = m_qb->itemData (i).toInt ();
+	Xmms::Coll::Universe univ;
+	std::list <std::string> arg;
+	std::string str;
 
-	QString q ("select distinct value from Media where key=");
-	if (t == MedialibSearchModel::SEARCH_ARTIST) {
-		q.append ("'artist'");
-	} else if (t == MedialibSearchModel::SEARCH_ALBUM) {
-		q.append ("'album'");
-	} else if (t == MedialibSearchModel::SEARCH_YEAR) {
-		q.append ("'date'");
-	} else if (t == MedialibSearchModel::SEARCH_TITLE) {
-		q.append ("'title'");
-	} else if (t == MedialibSearchModel::SEARCH_ALL) {
-		q.append ("'artist' or key = 'album'");
+	s.setValue ("medialib/searchdef", m_qb->currentIndex ());
+
+	if (t == MedialibSearchModel::ALL ||
+		t == MedialibSearchModel::TITLE) {
+		    if (m_completer) {
+                delete m_completer;
+            }
+            m_completer = new QCompleter (this);
+            m_le->setCompleter (m_completer);
+            return;
 	}
-	q.append (" order by lower (value)");
 
-	m_client->medialib.select (std::string (q.toUtf8 ()),
-							   Xmms::bind (&MedialibDialog::compl_reply, this));
+	if (t == MedialibSearchModel::ARTIST) {
+		str = std::string ("artist");
+	} else if (t == MedialibSearchModel::ALBUM) {
+		str = std::string ("album");
+	} else if (t == MedialibSearchModel::YEAR) {
+		str = std::string ("year");
+	}
+
+	m_currentsel = str;
+
+	arg.push_front (str);
+
+	m_client->collection.queryInfos (univ, arg, arg, 0, 0, arg) (Xmms::bind (&MedialibDialog::compl_reply, this));
 
 	m_le->setEnabled (false);
-	m_qb->setEnabled (false);
 	m_cb->setEnabled (false);
 	m_indicator->setStatus (true);
 }
@@ -140,7 +200,11 @@ MedialibDialog::compl_reply (const Xmms::List <Xmms::Dict> &list)
 	QStringList compl_list;
 
 	for (list.first (); list.isValid (); ++ list) {
-		compl_list.append (QString::fromUtf8 ((*list).get<std::string> ("value").c_str ()));
+		/* This seems to happen if a album is "" */
+		if ((*list).contains (m_currentsel)) {
+			QString qs = XClient::stdToQ ((*list).get<std::string> (m_currentsel));
+			compl_list.append (qs);
+		}
 	}
 
 	if (m_completer) {
@@ -151,7 +215,10 @@ MedialibDialog::compl_reply (const Xmms::List <Xmms::Dict> &list)
 	m_completer->setCaseSensitivity (Qt::CaseInsensitive);
 	m_le->setCompleter (m_completer);
 
-	search_done ();
+	m_le->setEnabled (true);
+	m_indicator->setStatus (false);
+	m_le->setFocus (Qt::OtherFocusReason);
+	m_cb->setEnabled (true);
 
 	return true;
 }
@@ -167,47 +234,34 @@ void
 MedialibDialog::plus_pressed (QMouseEvent *ev)
 {
 	QList<uint32_t> ids = m_list->get_selection ();
-	
+
 	if (ids.size () == 0) {
 		ids = m_list->get_all ();
 	}
 
 	for (int i = 0; i < ids.size (); i++) {
-		m_client->playlist.addId (ids.at (i), &XClient::log);
+		m_client->playlist.addId (ids.at (i)) ();
 	}
 }
 
 void
 MedialibDialog::search_done ()
 {
-	m_le->setEnabled (true);
-	m_indicator->setStatus (false);
-	m_le->setFocus (Qt::OtherFocusReason);
-	m_cb->setEnabled (true);
-	m_qb->setEnabled (true);
-}
-
-void
-MedialibDialog::search (int type, const QString &q, bool avail)
-{
-	m_qb->setCurrentIndex (type);
-	m_le->setText (q);
-	m_cb->setCheckState (avail ? Qt::Checked : Qt::Unchecked);
-	do_search ();
+    if (!m_browser->isVisible ()) {
+	    m_le->setEnabled (true);
+	    m_indicator->setStatus (false);
+	    m_le->setFocus (Qt::OtherFocusReason);
+	    m_cb->setEnabled (true);
+    }
 }
 
 void
 MedialibDialog::do_search ()
 {
-	QSettings s;
-
-	s.setValue ("medialib/searchdef", m_qb->currentIndex ());
-
-	m_list->do_search (m_qb->itemData (m_qb->currentIndex ()).toUInt (),
-					   m_le->displayText (), m_cb->checkState () == Qt::Checked);
+	m_list->search (m_qb->itemData (m_qb->currentIndex ()).toUInt (),
+				    m_le->displayText (), m_cb->checkState () == Qt::Checked);
 	m_le->setEnabled (false);
 	m_cb->setEnabled (false);
-	m_qb->setEnabled (false);
 	m_indicator->setStatus (true);
 }
 
