@@ -15,6 +15,7 @@
  */
 
 
+
 #ifndef __MEDIALIBDIALOG_H__
 #define __MEDIALIBDIALOG_H__
 
@@ -22,13 +23,16 @@
 #include <QLineEdit>
 #include <QComboBox>
 #include <QCheckBox>
-#include <QDialog>
+#include <QMainWindow>
 #include <QCompleter>
 
+class MedialibDialog;
+
 #include "medialibview.h"
 #include "progressindicator.h"
+#include "medialibpanebrowser.h"
 
-class MedialibDialog : public QDialog
+class MedialibDialog : public QMainWindow
 {
 	Q_OBJECT
 
@@ -37,13 +41,17 @@ class MedialibDialog : public QDialog
 
 		void resizeEvent (QResizeEvent *);
 		void keyPressEvent (QKeyEvent *);
-		void search (int, const QString &, bool a = false);
-
+        void set_list_coll (const Xmms::Coll::Coll &coll)
+        {
+            m_list->set_collection (coll);
+        };
+        
 	private slots:
 		void do_search ();
 		void search_done ();
 		void plus_pressed (QMouseEvent *);
 		void load_compl_list (int);
+        void expand_clicked ();
 
 	private:
 		bool compl_reply (const Xmms::List < Xmms::Dict > &);
@@ -58,7 +66,10 @@ class MedialibDialog : public QDialog
 		XClient *m_client;
 
 		ProgressIndicator *m_indicator;
+        MedialibPaneBrowser *m_browser;
 
+		std::string m_currentsel;
 };
 
 #endif
+
