@@ -15,6 +15,7 @@
  */
 
 
+
 #include "medialibview.h"
 #include "medialibsearchmodel.h"
 #include <QSettings>
@@ -30,7 +31,6 @@ MedialibView::MedialibView (QWidget *parent, XClient *client) : QTreeView (paren
 	setAlternatingRowColors (true);
 	setItemsExpandable (false);
 	setRootIsDecorated (false);
-	setDragEnabled (true);
 
     setSelectionMode (QAbstractItemView::ExtendedSelection);
     setSelectionBehavior (QAbstractItemView::SelectRows);
@@ -63,8 +63,8 @@ MedialibView::head_size (int c, int o, int n)
 void
 MedialibView::add_id (const QModelIndex &idx)
 {
-	uint32_t id = idx.data (MedialibSearchModel::MedialibIdRole).toUInt ();
-	m_client->playlist.addId (id, &XClient::log);
+	uint32_t id = idx.data (CollectionModel::MedialibIdRole).toUInt ();
+    m_client->playlist.addId (id) ();
 }
 
 void
@@ -84,7 +84,7 @@ MedialibView::get_selection ()
 		if (idx.column () != 0)
 			continue;
 
-		ret.append (idx.data (MedialibSearchModel::MedialibIdRole).toUInt ());
+		ret.append (idx.data (CollectionModel::MedialibIdRole).toUInt ());
 	}
 
 	return ret;
@@ -93,5 +93,5 @@ MedialibView::get_selection ()
 QList<uint32_t>
 MedialibView::get_all ()
 {
-	return m_model->get_all_id ();
+    return m_model->get_idlist ();
 }
