@@ -15,6 +15,7 @@
  */
 
 
+
 #ifndef __MEDIALIBVIEW_H__
 #define __MEDIALIBVIEW_H__
 
@@ -30,13 +31,18 @@ class MedialibView : public QTreeView
 	public:
 		MedialibView (QWidget *, XClient *);
 
-		void do_search (uint32_t p, const QString &s, bool a)
+		void search (uint32_t p, const QString &s, bool a)
 		{
-			m_model->do_search (p, s, a);
+            m_model->search (p, s, a);
 		};
 
 		QList<uint32_t> get_selection ();
 		QList<uint32_t> get_all ();
+		
+        void set_collection (const Xmms::Coll::Coll &coll)
+        {
+            m_model->set_collection (coll);
+        };
 
 	private slots:
 		void search_done ();
@@ -53,3 +59,4 @@ class MedialibView : public QTreeView
 };
 
 #endif
+
