@@ -1,4 +1,4 @@
-/** 
+/**
  *  This file is a part of Esperanza, an XMMS2 Client.
  *
  *  Copyright (C) 2005-2006 XMMS2 Team
@@ -36,11 +36,9 @@
 
 #include "playerwidget.h"
 #include "playerbutton.h"
-#include "playlistview.h"
+#include "fancyplaylistview.h"
 #include "progressframe.h"
 #include "filedialog.h"
-#include "browsedialog.h"
-#include "medialibdialog.h"
 #include "preferences.h"
 #include "volumebar.h"
 #include "textdialog.h"
@@ -49,6 +47,9 @@
 #include "minimode.h"
 #include "jumptofiledialog.h"
 #include "lastfm.h"
+#include "medialibdialog.h"
+#include "streamingdialog.h"
+/*#include "collections/manager.h"*/
 
 
 PlayerWidget::PlayerWidget (QWidget *parent, XClient *client) : QMainWindow (parent)
@@ -69,13 +70,13 @@ PlayerWidget::PlayerWidget (QWidget *parent, XClient *client) : QMainWindow (par
 	QWidget *dummy = new QWidget (main_w);
 
 	QGridLayout *layout = new QGridLayout (main_w);
-	m_playlist = new PlaylistView (this, client);
+	m_playlist = new FancyPlaylistView (this, client);
 	layout->addWidget (m_playlist, 1, 0, 1, 3);
 
 	QHBoxLayout *pflay = new QHBoxLayout ();
 	pflay->setMargin (0);
 
-	m_pf = new ProgressFrame (this);
+	m_pf = new ProgressFrame (this, client);
 	pflay->addWidget (m_pf);
 	pflay->setStretchFactor (m_pf, 1);
 
@@ -153,7 +154,7 @@ PlayerWidget::PlayerWidget (QWidget *parent, XClient *client) : QMainWindow (par
 
 	m_current_id = 0;
 	connect (client, SIGNAL (gotConnection (XClient *)),
-			 this, SLOT (got_connection (XClient *))); 
+			 this, SLOT (got_connection (XClient *)));
 
 	resize (s.value ("player/windowsize", QSize (550, 350)).toSize());
 	if (s.contains ("player/position"))
@@ -174,9 +175,9 @@ PlayerWidget::PlayerWidget (QWidget *parent, XClient *client) : QMainWindow (par
 	m->addAction (tr ("Add local file"), this, SLOT (add_local_file ()));
 	m->addAction (tr ("Add local dir"), this, SLOT (add_local_dir ()));
 	m->addSeparator ();
+	/*
 	m->addAction (tr ("Add remote file"), this, SLOT (add_remote_file ()));
-	m->addSeparator ();
-	m->addAction (tr ("Add files from medialib"), this, SLOT (show_medialib ()));
+	*/
 	m = menuBar ()->addMenu (tr ("Help"));
 	m->addAction (tr ("Esperanza Help"), this, SLOT (open_short_help ()));
 #endif
@@ -201,12 +202,26 @@ PlayerWidget::PlayerWidget (QWidget *parent, XClient *client) : QMainWindow (par
 	connect (m_playlist, SIGNAL (selectedID (uint32_t)), m_lastfm, SLOT (new_id (uint32_t)));
 
 	m_mini = new MiniMode (this, m_client);
-	m_mini->hide ();
-	
+
+    m_streaming = NULL;
+
 	/* run it once first time */
 	changed_settings ();
 }
 
+void
+PlayerWidget::toggle_mini () const
+{
+	QSettings s;
+
+	if (m_mini->isVisible () && m_mini->isActiveWindow ()) {
+		m_mini->hide ();
+	} else {
+		m_mini->hide ();
+		m_mini->show ();
+	}
+}
+
 void
 PlayerWidget::closeEvent (QCloseEvent *ev)
 {
@@ -221,6 +236,8 @@ PlayerWidget::set_colors ()
 void
 PlayerWidget::min_pressed ()
 {
+	QSettings s;
+	s.setValue ("ui/minimode", true);
 	m_mini->show ();
 	hide ();
 }
@@ -239,7 +256,7 @@ PlayerWidget::changed_settings ()
 
 	if (s.value ("ui/reverseplaytime").toBool ())
 		m_pf->setReverse (true);
-	
+
 	if (m_systray) {
 		if ( s.value ("core/systray").toBool ())
 			m_systray->show();
@@ -273,14 +290,15 @@ PlayerWidget::keyPressEvent (QKeyEvent *ev)
 		ev->ignore ();
 		return;
 	}
-	
+
 	switch (ev->key ()) {
 		case Qt::Key_Backspace:
 		case Qt::Key_Delete:
-			/* a little hack here */
-			m_playlist->set_removed (true);
 			remove_selected ();
 			break;
+		case Qt::Key_M:
+			mlib_pressed ();
+			break;
 		case Qt::Key_S:
 			shuffle_pressed ();
 			break;
@@ -288,7 +306,9 @@ PlayerWidget::keyPressEvent (QKeyEvent *ev)
 			add_local_file ();
 			break;
 		case Qt::Key_R:
+			/*
 			add_remote_file ();
+			*/
 			break;
 		case Qt::Key_D:
 			add_local_dir ();
@@ -296,9 +316,6 @@ PlayerWidget::keyPressEvent (QKeyEvent *ev)
 		case Qt::Key_C:
 			remove_all ();
 			break;
-		case Qt::Key_M:
-			show_medialib ();
-			break;
 		case Qt::Key_Enter:
 		case Qt::Key_Return:
 			m_playlist->jump_pos (QModelIndex ());
@@ -340,6 +357,13 @@ PlayerWidget::keyPressEvent (QKeyEvent *ev)
 	}
 }
 
+void
+PlayerWidget::mlib_pressed ()
+{
+	MedialibDialog *d = new MedialibDialog (this, m_client);
+	d->show ();
+}
+
 void
 PlayerWidget::lastfm_pressed ()
 {
@@ -349,49 +373,37 @@ PlayerWidget::lastfm_pressed ()
 void
 PlayerWidget::jump_pressed ()
 {
+	/*
 	JumpToFileDialog d (this, m_playlist->model ());
 	if (d.exec ()) {
 		QModelIndex idx = d.sel_item ();
 		if (idx.isValid ()) {
 			m_playlist->setCurrentIndex (idx);
 		}
-	}
+	}*/
 }
 
 void
 PlayerWidget::play_pressed ()
 {
 	if (m_status == Xmms::Playback::PLAYING)
-		m_client->playback.pause (&XClient::log);
+		m_client->playback.pause () ();
 	else
-		m_client->playback.start (&XClient::log);
-}
-
-static bool
-dummy_uint (const uint32_t &)
-{
-	return false;
+		m_client->playback.start () ();
 }
 
 void
 PlayerWidget::fwd_pressed ()
 {
-	m_client->playlist.setNextRel (1, &dummy_uint);
-	m_client->playback.tickle (&XClient::log);
+	m_client->playlist.setNextRel (1) ();
+	m_client->playback.tickle () ();
 }
 
 void
 PlayerWidget::back_pressed ()
 {
-	m_client->playlist.setNextRel (-1, &dummy_uint);
-	m_client->playback.tickle (&XClient::log);
-}
-
-void
-PlayerWidget::show_medialib ()
-{
-	MedialibDialog *mb = new MedialibDialog (this, m_client);
-	mb->show ();
+	m_client->playlist.setNextRel (-1) ();
+	m_client->playback.tickle () ();
 }
 
 void
@@ -401,10 +413,12 @@ PlayerWidget::plus_pressed (QMouseEvent *ev)
 
 	m.addAction (tr ("Add local file"), this, SLOT (add_local_file ()));
 	m.addAction (tr ("Add local dir"), this, SLOT (add_local_dir ()));
+	m.addAction (tr ("Search medialib"), this, SLOT (mlib_pressed ()));
 	m.addSeparator ();
+	/*
 	m.addAction (tr ("Add remote file"), this, SLOT (add_remote_file ()));
-	m.addSeparator ();
-	m.addAction (tr ("Add files from medialib"), this, SLOT (show_medialib ()));
+	*/
+	m.addAction (tr ("Add URL"), this, SLOT (add_url ()));
 
 	m.exec (ev->globalPos ());
 }
@@ -414,6 +428,8 @@ PlayerWidget::info_pressed (QMouseEvent *ev)
 {
 	QMenu m;
 	m.addAction (tr ("Last.fm browser"), this, SLOT (lastfm_pressed ()));
+	m.addAction (tr ("Stream directory"), this, SLOT (streaming_pressed ()));
+/*	m.addAction (tr ("Collection Manager"), this, SLOT (coll_pressed ()));*/
 	m.addSeparator ();
 	m.addAction (tr ("Keyboard shortcuts"), this, SLOT (open_short_help ()));
 	m.addAction (tr ("About Esperanza"), this, SLOT (open_about ()));
@@ -421,6 +437,30 @@ PlayerWidget::info_pressed (QMouseEvent *ev)
 	m.exec (ev->globalPos ());
 }
 
+void
+PlayerWidget::streaming_pressed ()
+{
+    if (m_streaming) {
+        if (!m_streaming->isVisible ()) {
+            m_streaming->show ();
+        } else {
+            m_streaming->hide ();
+        }
+    } else {
+	    m_streaming = new StreamingDialog (this, m_client);
+	    m_streaming->show ();
+    }
+}
+
+void
+PlayerWidget::coll_pressed ()
+{
+	/*
+	CollectionManager *coll = new CollectionManager (this, m_client);
+	coll->show ();
+	*/
+}
+
 void
 PlayerWidget::snett_pressed (QMouseEvent *ev)
 {
@@ -435,7 +475,7 @@ PlayerWidget::snett_pressed (QMouseEvent *ev)
 void
 PlayerWidget::shuffle_pressed ()
 {
-	m_client->playlist.shuffle (&XClient::log);
+	m_client->playlist.shuffle () ();
 }
 
 /*
@@ -470,14 +510,25 @@ PlayerWidget::open_pref ()
 	pd->show ();
 }
 
+void
+PlayerWidget::add_url ()
+{
+	bool ok;
+	QString url = QInputDialog::getText (this, tr ("URL dialog"), tr ("Enter URL:"),
+										 QLineEdit::Normal, "http://", &ok);
+	if (ok && !url.isEmpty ()) {
+		m_client->playlist.addUrl (XClient::qToStd (url)) ();
+	}
+}
+
 void
 PlayerWidget::add_remote_file ()
 {
-	BrowseDialog bd (window (), m_client);
-	QStringList files = bd.getFiles ();
+	FileDialog fd (this, "remote_file", true);
+	QStringList files = fd.getFiles ();
 
 	for (int i = 0; i < files.count(); i++) {
-		m_client->playlist.addUrlEncoded (files.value (i).toStdString (), &XClient::log);
+		m_client->playlist.addUrlEncoded (files.value (i).toStdString ()) ();
 	}
 
 }
@@ -488,7 +539,7 @@ PlayerWidget::add_local_dir ()
 	FileDialog fd (this, "playlist_add_dir");
 	QString dir = fd.getDirectory ();
 	if (!dir.isNull ())
-		m_client->playlist.addRecursive (("file://" + dir).toStdString (), &XClient::log);
+		m_client->playlist.addRecursive (XClient::qToStd ("file://" + dir)) ();
 }
 
 void
@@ -501,7 +552,7 @@ PlayerWidget::add_local_file ()
 
 	for (int i = 0; i < files.count(); i++) {
 		QString s = "file://" + files.at (i);
-		m_client->playlist.addUrl (s.toStdString (), &XClient::log);
+		m_client->playlist.addUrl (XClient::qToStd (s)) ();
 	}
 
 }
@@ -533,20 +584,20 @@ PlayerWidget::remove_selected ()
 
 	qSort (idlist);
 	for (int i = idlist.size () - 1; i > -1; i --) {
-		m_client->playlist.remove (idlist.at (i), &XClient::log);
+		m_client->playlist.removeEntry (idlist.at (i)) ();
 	}
 }
 
 void
 PlayerWidget::playstop_pressed ()
 {
-	m_client->playback.stop (&XClient::log);
+	m_client->playback.stop () ();
 }
 
 void
 PlayerWidget::remove_all ()
 {
-	m_client->playlist.clear (&XClient::log);
+	m_client->playlist.clear () ();
 }
 
 void
@@ -554,16 +605,16 @@ PlayerWidget::got_connection (XClient *client)
 {
 	m_client = client;
 
-	client->playback.signalPlaytime (Xmms::bind (&PlayerWidget::handle_playtime, this));
-	client->playback.getPlaytime (Xmms::bind (&PlayerWidget::handle_playtime, this));
+	client->playback.signalPlaytime () (Xmms::bind (&PlayerWidget::handle_playtime, this));
+	client->playback.getPlaytime () (Xmms::bind (&PlayerWidget::handle_playtime, this));
 
-	client->playback.getStatus (Xmms::bind (&PlayerWidget::handle_status, this));
-	client->playback.broadcastStatus (Xmms::bind (&PlayerWidget::handle_status, this));
+	client->playback.getStatus () (Xmms::bind (&PlayerWidget::handle_status, this));
+	client->playback.broadcastStatus () (Xmms::bind (&PlayerWidget::handle_status, this));
 
 	client->setDisconnectCallback (boost::bind (&PlayerWidget::handle_disconnect, this));
 
-	client->playback.broadcastCurrentID (Xmms::bind (&PlayerWidget::handle_current_id, this));
-	client->playback.currentID (Xmms::bind (&PlayerWidget::handle_current_id, this));
+	client->playback.broadcastCurrentID () (Xmms::bind (&PlayerWidget::handle_current_id, this));
+	client->playback.currentID () (Xmms::bind (&PlayerWidget::handle_current_id, this));
 
 	/* XXX: broken in c++ bindings
 	client->stats.broadcastMediainfoReaderStatus (Xmms::bind (&PlayerWidget::handle_index_status, this));
@@ -575,7 +626,7 @@ void
 PlayerWidget::handle_disconnect ()
 {
 	QErrorMessage *err = new QErrorMessage (this);
-	err->showMessage (tr ("Server died. The application will now quit."));
+	err->showMessage (tr ("Server died. Esperanza will close."));
 	err->exec ();
 	QApplication::quit ();
 }
@@ -594,6 +645,10 @@ PlayerWidget::handle_status (const Xmms::Playback::Status &st)
 		m_mini->update_playbutton (":images/pause.png");
 	}
 
+	if (st == Xmms::Playback::STOPPED) {
+		m_pf->setValue (0);
+	}
+
 	return true;
 }
 
@@ -608,9 +663,15 @@ PlayerWidget::entry_changed (uint32_t id)
 void
 PlayerWidget::new_info (const QHash<QString,QVariant> &h)
 {
-	QString s = QString ("%2 - %3")
-		.arg(h["artist"].toString ())
-		.arg(h["title"].toString ());
+	QString s;
+	if (!h.contains ("title")) {
+		s = h["url"].toString ();
+	} else {
+		s = QString ("%1 - %2")
+			.arg(h["artist"].toString ())
+			.arg(h["title"].toString ());
+	}
+
 	m_pf->setText (s);
 	m_mini->setText (s);
 
@@ -626,11 +687,10 @@ PlayerWidget::new_info (const QHash<QString,QVariant> &h)
 		m_current_id == h["id"].toUInt () &&
         m_status == Xmms::Playback::PLAYING &&
         h["id"].toUInt () != 0) {
-		m_systray->do_notification (tr("Esperanza is now playing:"), s, m_client->cache ()->get_pixmap (m_current_id));
+		m_systray->do_notification (tr ("Esperanza is now playing:"), s, m_client->cache ()->get_pixmap (m_current_id));
 	}
 }
 
-
 bool
 PlayerWidget::handle_playtime (const unsigned int &tme)
 {
