@@ -24,7 +24,7 @@
 #include <QMouseEvent>
 #include <QAction>
 
-#include "playlistview.h"
+#include "fancyplaylistview.h"
 #include "progressframe.h"
 #include "playerbutton.h"
 #include "volumebar.h"
@@ -32,6 +32,7 @@
 #include "infowindow.h"
 #include "minimode.h"
 #include "lastfm.h"
+#include "streamingdialog.h"
 
 class PlayerWidget : public QMainWindow
 {
@@ -48,15 +49,23 @@ class PlayerWidget : public QMainWindow
 		void resizeEvent (QResizeEvent *);
 		void moveEvent (QMoveEvent *);
 		void closeEvent (QCloseEvent *);
+		
+		void toggle_mini () const;
 
-		void hide_mini () const
+		bool mini_isactive () const
 		{
-			m_mini->hide ();
+			return m_mini->isActiveWindow ();
+		};
+
+		bool mini_isvisible () const
+		{
+			return m_mini->isVisible ();
 		};
 
 	public slots:
 		void play_pressed ();
 		void lastfm_pressed ();
+		void coll_pressed ();
 		void playstop_pressed ();
 		void fwd_pressed ();
 		void back_pressed ();
@@ -72,12 +81,14 @@ class PlayerWidget : public QMainWindow
 		void add_remote_file ();
 		void add_local_file ();
 		void add_local_dir ();
+		void add_url ();
 		void min_pressed ();
+		void mlib_pressed ();
+		void streaming_pressed ();
 
 		void remove_selected ();
 		void remove_all ();
 
-		void show_medialib ();
 		void entry_changed (uint32_t);
 
 		void open_pref ();
@@ -89,7 +100,7 @@ class PlayerWidget : public QMainWindow
 	private:
 		XClient *m_client;
 		Xmms::Playback::Status m_status;
-		PlaylistView *m_playlist;
+		FancyPlaylistView *m_playlist;
 		PlayerButton *m_playbutt;
 		PlayerButton *m_playstop;
 
@@ -112,6 +123,7 @@ class PlayerWidget : public QMainWindow
 		MiniMode *m_mini;
 
 		LastFmDialog *m_lastfm;
+        StreamingDialog *m_streaming;
 
 };
 
