@@ -40,7 +40,7 @@
 #include <QPainter>
 
 
-ProgressFrame::ProgressFrame( QWidget *parent ) :
+ProgressFrame::ProgressFrame (QWidget *parent, XClient *client, bool seek) :
     QFrame( parent ),
     m_drawBackground( true ),
     m_drawTime( false ),
@@ -57,12 +57,14 @@ ProgressFrame::ProgressFrame( QWidget *parent ) :
 
     m_maxValue = 0;
     m_value = 0;
+	m_seek = seek;
 
     setMinimumHeight( 22 );
     setMinimumWidth( 22 );
     setFrameStyle( QFrame::StyledPanel | QFrame::Sunken );
     setLineWidth( 1 );
 
+	m_client = client;
 }
 
 
@@ -284,6 +286,14 @@ ProgressFrame::mousePressEvent (QMouseEvent *event)
 	QPoint p = mapTo (window (), event->pos ());
 	m_diffx = p.x ();
 	m_diffy = p.y ();
+
+	/* some windows showing this don't want to seek */
+	if (m_seek) {
+		float pro = (float) m_diffx / (float) width ();
+		uint32_t m = (uint32_t) (pro * m_maxValue * 1000);
+
+		m_client->playback.seekMs (m) ();
+	}
 }
 
 void
